@@ -77,7 +77,7 @@ class Vector2D(object):
         """Get the magnitude squared of the vector."""
         return self.x ** 2 + self.y ** 2
 
-    def is_zero(self, tolerance=0):
+    def is_zero(self, tolerance):
         """Boolean to note whether the vector is within a given zero tolerance.
 
         Args:
@@ -426,4 +426,3 @@ class Point2D(Vector2D):
         """
         if isinstance(other, Vector2D):
             return self.x > other.x
-
