@@ -211,14 +211,14 @@ class Polygon2D(Base2DIn2D):
                 'hole should have at least 3 vertices. Got {}'.format(len(hole))
 
         # check that the direction of vertices for the hole is opposite the boundary
-        bound_direction = Polygon2D._are_clockwise(boundary)
+        bound_direction = cls._are_clockwise(boundary)
         for hole in holes:
-            if Polygon2D._are_clockwise(hole) is bound_direction:
+            if cls._are_clockwise(hole) is bound_direction:
                 hole.reverse()
 
         # recursively add the nearest hole to the boundary until there are none left.
         while len(holes) > 0:
-            boundary, holes = Polygon2D._merge_boundary_and_closest_hole(boundary, holes)
+            boundary, holes = cls._merge_boundary_and_closest_hole(boundary, holes)
 
         # return the polygon with some properties set based on what we know
         _new_poly = cls(boundary)
@@ -907,7 +907,14 @@ class Polygon2D(Base2DIn2D):
         return _a < 0
 
     def __copy__(self):
-        return Polygon2D(self._vertices)
+        _new_poly = Polygon2D(self._vertices)
+        _new_poly._segments = self._segments
+        _new_poly._perimeter = self._perimeter
+        _new_poly._area = self._area
+        _new_poly._is_clockwise = self._is_clockwise
+        _new_poly._is_convex = self._is_convex
+        _new_poly._is_self_intersecting = self._is_self_intersecting
+        return _new_poly
 
     def __key(self):
         """A tuple based on the object properties, useful for hashing."""
